Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPhilipe Mulet2007-04-12 10:37:18 +0000
committerPhilipe Mulet2007-04-12 10:37:18 +0000
commiteadf5ba6d44f28f071965cf829d67590b0a71974 (patch)
tree33e2486c0a79935c0fd3bded6be91b252b9cd2b7 /org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
parentb418235473d69146fcb35be10bf158bb2b040cf7 (diff)
downloadeclipse.jdt.core-eadf5ba6d44f28f071965cf829d67590b0a71974.tar.gz
eclipse.jdt.core-eadf5ba6d44f28f071965cf829d67590b0a71974.tar.xz
eclipse.jdt.core-eadf5ba6d44f28f071965cf829d67590b0a71974.zip
146556
Diffstat (limited to 'org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java')
-rw-r--r--org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java8
1 files changed, 6 insertions, 2 deletions
diff --git a/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java b/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
index 677bcbe1e6..882c679d5b 100644
--- a/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
+++ b/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
@@ -27,7 +27,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
public final static int Bit2 = 0x2; // return type (operator) | name reference kind (name ref) | has local type (type, method, field decl)
public final static int Bit3 = 0x4; // return type (operator) | name reference kind (name ref) | implicit this (this ref)
public final static int Bit4 = 0x8; // return type (operator) | first assignment to local (name ref,local decl) | undocumented empty block (block, type and method decl)
- public final static int Bit5 = 0x10; // value for return (expression) | has all method bodies (unit) | supertype ref (type ref)
+ public final static int Bit5 = 0x10; // value for return (expression) | has all method bodies (unit) | supertype ref (type ref) | resolved (field decl)
public final static int Bit6 = 0x20; // depth (name ref, msg) | ignore need cast check (cast expression)
public final static int Bit7 = 0x40; // depth (name ref, msg) | operator (operator) | need runtime checkcast (cast expression) | label used (labelStatement)
public final static int Bit8 = 0x80; // depth (name ref, msg) | operator (operator) | unsafe cast (cast expression)
@@ -36,7 +36,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
public final static int Bit11 = 0x400; // depth (name ref, msg) | operator (operator) | is member type (type decl)
public final static int Bit12 = 0x800; // depth (name ref, msg) | operator (operator) | has abstract methods (type decl)
public final static int Bit13 = 0x1000; // depth (name ref, msg) | is secondary type (type decl)
- public final static int Bit14 = 0x2000; // strictly assigned (reference lhs)
+ public final static int Bit14 = 0x2000; // strictly assigned (reference lhs) | discard enclosing instance (explicit constr call)
public final static int Bit15 = 0x4000; // is unnecessary cast (expression) | is varargs (type ref) | isSubRoutineEscaping (try statement)
public final static int Bit16 = 0x8000; // in javadoc comment (name ref, type ref, msg)
public final static int Bit17 = 0x10000; // compound assigned (reference lhs)
@@ -141,6 +141,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
// for type, method and field declarations
public static final int HasLocalType = Bit2; // cannot conflict with AddAssertionMASK
+ public static final int HasBeenResolved = Bit5; // field decl only (to handle forward references)
// for expression
public static final int ParenthesizedSHIFT = 21; // Bit22 -> Bit29
@@ -151,6 +152,9 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
public static final int IsStrictlyAssigned = Bit14; // set only for true assignments, as opposed to compound ones
public static final int IsCompoundAssigned = Bit17; // set only for compound assignments, as opposed to other ones
+ // for explicit constructor call
+ public static final int DiscardEnclosingInstance = Bit14; // used for codegen
+
// for empty statement
public static final int IsUsefulEmptyStatement = Bit1;

Back to the top